<?php

namespace App\Models;

use Auth;
use Illuminate\Database\Eloquent\Model;
use Kalnoy\Nestedset\NodeTrait;

class Category extends Model
{
    use NodeTrait;

    protected $fillable = ['name', 'parent_id', 'image', 'restaurant_id', 'city_id'];

    protected $appends = ['has_children', 'image_url', 'products_count'];
    protected $hidden = ['image'];

    public function products()
    {
        return $this->hasMany('App\Models\Product');
    }

    public function restaurant()
    {
        return $this->belongsTo(Restaurant::class);
    }

	public function getProductsCountAttribute()
	{
		return $this->products()->count();
	}

    public function getHasChildrenAttribute()
    {
      return $this->children()->count();
    }

    public function getImageUrlAttribute()
    {
      return url($this->image);
    }

    /**
     * Relation of models accessible by current user
     * @return Relation
     */
    public static function policyScope()
    {
        $user = Auth::user();
        if ($user->restaurants->count() > 0 && (Settings::getSettings()->multiple_restaurants || Settings::getSettings()->multiple_cities)) {
            return Category::whereIn('restaurant_id', $user->restaurants->pluck('id')->all())->
                orderBy('sort', 'ASC');
        }
        else {
            if ($user->access_full || !Settings::getSettings()->multiple_cities) {
                return Category::withDepth()->defaultOrder();
            } else {
                return Category::withDepth()->defaultOrder()->whereIn('city_id', $user->cities->pluck('id')->all());
            }
        }
    }
}
