<?php

namespace App\Policies;

use App\Models\User;
use App\Models\DeliveryBoy;
use Illuminate\Auth\Access\HandlesAuthorization;

class DeliveryBoyPolicy
{
    use HandlesAuthorization;

    protected function tgAccess(User $user, DeliveryBoy $deliveryBoy)
    {
        return $user->access_full || $user->access_delivery_boys;
    }

    /**
     * Determine whether the user can view the deliveryBoy.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\NewsItem  $deliveryBoy
     * @return mixed
     */
    public function view(User $user, DeliveryBoy $deliveryBoy)
    {
        return $this->tgAccess($user, $deliveryBoy);
    }

    /**
     * Determine whether the user can create taxGroups.
     *
     * @param  \App\Models\User  $user
     * @return mixed
     */
    public function create(User $user)
    {
        return $this->tgAccess($user, new DeliveryBoy());
    }

    /**
     * Determine whether the user can update the deliveryBoy.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\NewsItem  $deliveryBoy
     * @return mixed
     */
    public function update(User $user, DeliveryBoy $deliveryBoy)
    {
        return $this->tgAccess($user, $deliveryBoy);
    }

    /**
     * Determine whether the user can delete the deliveryBoy.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\NewsItem  $deliveryBoy
     * @return mixed
     */
    public function delete(User $user, DeliveryBoy $deliveryBoy)
    {
        return $this->tgAccess($user, $deliveryBoy);
    }
}
