<?php

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\Api\SettingsController;
use App\Http\Controllers\Api\VendorsController;
use App\Http\Controllers\Api\RestaurantsController;
use App\Http\Controllers\Api\CategoriesController;
use App\Http\Controllers\Api\DeliveryAreasController;
use App\Http\Controllers\Api\ProductsController;
use App\Http\Controllers\Api\OrdersController;
use App\Http\Controllers\Api\PromoCodesController;
use App\Http\Controllers\Api\NewsItemsController;
use App\Http\Controllers\Api\CustomersController;
use App\Http\Controllers\Api\DriversController;
use App\Http\Controllers\Api\MessagesController;
use App\Http\Controllers\Api\ContactUsController;
use App\Http\Controllers\Api\SearchController;

/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| is assigned the "api" middleware group. Enjoy building your API!
|
*/

Route::group(['namespace' => 'Api', 'middleware' => ['cors']], function () {
	Route::get('/search', [SearchController::class, 'total']);
	Route::get('/welcome_page_restaurants', [RestaurantsController::class, 'welcome']);
    Route::get('/vendors', [VendorsController::class, 'index']);
    Route::get('/categories', [CategoriesController::class, 'index']);
    Route::get('/restaurants', [RestaurantsController::class, 'index']);
    Route::get('/delivery_areas', [DeliveryAreasController::class, 'index']);
    Route::get('/products', [ProductsController::class, 'index']);
    Route::get('/products/{id}', [ProductsController::class, 'show']);
    Route::get('/news', [NewsItemsController::class, 'index']);
    Route::post('/order', [OrdersController::class, 'create']);
    Route::post('/promo_codes/validate', [PromoCodesController::class, 'validate_code']);
    Route::get('/settings', [SettingsController::class, 'index']);
    Route::post('/customers', [CustomersController::class, 'create']);
    Route::post('/login', [CustomersController::class, 'login'])->name('customers.login');
    Route::post('/contact_us', [ContactUsController::class, 'send'])->name('contact_us.send');
    Route::group(['middleware' => ['app_user_auth']], function () {
        Route::get('/tracker', [OrdersController::class, 'tracker']);
        Route::post('/push_token_cust', [CustomersController::class, 'push']);
        Route::get('/me', [CustomersController::class, 'me']);
        Route::put('/customers/1', [CustomersController::class, 'update']);
        Route::get('/orders', [OrdersController::class, 'index']);
        Route::post('/rate_order', [OrdersController::class, 'rate'])->name('orders.rate');
    });

    Route::post('/driver_login', [DriversController::class, 'login']);
    Route::group(['middleware' => ['drivers_auth']], function () {
        Route::put('/drivers/1', [DriversController::class, 'update']);
        Route::post('/push_token', [DriversController::class, 'save_push_token']);
        Route::post('/order_status', [OrdersController::class, 'setStatus']);
        Route::get('/driver_orders', [OrdersController::class, 'indexDriver']);
        Route::get('/messages', [MessagesController::class, 'index']);
        Route::post('/read_message', [MessagesController::class, 'read']);
    });
});
